import re

__package__    = "machinetag"
__version__    = "1.0"
__author__     = "Aaron Straup Cope"
__url__        = "http://www.aaronland.info/python/machinetag/"
__cvsversion__ = "$Revision: 1.1 $"
__date__       = "$Date: 2007/08/26 19:22:06 $"
__copyright__  = "Copyright (c) 2006 Aaron Straup Cope. Perl Artistic License."

class machinetag :

    def __init__ (self, ns_or_tagraw, pred=None, value=None) :

        self.__namespace__ = None
        self.__predicate__ = None
        self.__value__ = None
        
        if pred :

            re_nspred = re.compile(r"^([a-z](?:[a-z0-9_]+))$")

            if re_nspred.match(ns_or_tagraw) and re_nspred.match(pred) and value :
                self.__namespace__ = ns_or_tagraw
                self.__predicate__ = pred
                self.__value__ = value
        else :

            re_tag = re.compile(r"^([a-z](?:[a-z0-9_]+))\:([a-z](?:[a-z0-9_]+))\=(.+)$")
            m = re_tag.findall(ns_or_tagraw)

            if m :
                self.__namespace__ = m[0][0]
                self.__predicate__ = m[0][1]
                self.__value__ = m[0][2]

    def __str__ (self) :
        return self.as_string()
            
    def __unicode__ (self) :
        return self.as_string()

    def is_machinetag (self) :
        if self.__namespace__ and self.__predicate__ and self.__value__ :
            return True

        return False
    
    def namespace (self) :
        return self.__namespace__

    def predicate (self) :
        return self.__predicate__

    def value (self) :
        return self.__value__
    
    def as_string (self) :
        if self.is_machinetag() :
            return "%s:%s=%s" % (self.namespace(), self.predicate(), self.value())

if __name__ == "__main__" :

    str_mt = "flickr:user=straup"

    mt1 = machinetag(str_mt)

    if mt1.is_machinetag() :
        print "MT1 : %s" % mt1
        print "MT1 namespace : %s" % mt1.namespace()
        
    mt2 = machinetag("aero", "airport", "SFO")

    if mt2.is_machinetag() :
        print "MT2 : %s" % mt2
